/**
 * Copyright (C) 2015 - 2018 Kosmos contact@kosmos.fr
 *
 * Projet: rechercheetlabo
 * Version: 1.08.00
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.ksup.objetspartages.bean;

import com.kportal.cms.objetspartages.annotation.strategy.DatLabelStrategy;
import org.apache.commons.lang3.StringUtils;

import com.kportal.cms.objetspartages.annotation.Autocompletion;
import com.kportal.cms.objetspartages.annotation.Fiche;
import com.kportal.cms.objetspartages.annotation.GetterAnnotation;
import com.kportal.cms.objetspartages.annotation.Label;
import com.kportal.cms.objetspartages.annotation.SetterAnnotation;
import com.univ.objetspartages.bean.AbstractRestrictionFicheBean;
import com.univ.objetspartages.bean.StructureBean;

/**
 * The Class LaboratoireBean.
 */
public class LaboratoireBean extends StructureBean {

    /** The libelle court. */
    @Autocompletion(name = "titre_completion")
    private String libelleCourt = StringUtils.EMPTY;

    /** The libelle long. */
    @Autocompletion(name = "titre_completion")
    private String libelleLong = StringUtils.EMPTY;

    /** The type laboratoire. */
    @Label(contexte = "rechercheetlabo", type = "63")
    private String typeLaboratoire = StringUtils.EMPTY;

    /** The structure enseignement. */
    private String structureEnseignement = StringUtils.EMPTY;

    /** The reference umr. */
    private String referenceUmr = StringUtils.EMPTY;

    /** The reconnaissance. */
    private String reconnaissance = StringUtils.EMPTY;

    /** The direction scientifique. Correspond au département scientifique */
    @Label(contexte = "rechercheetlabo", type = "direction_scientifique", strategy = DatLabelStrategy.class)
    private String directionScientifique = StringUtils.EMPTY;

    /** The code rattachement autres. */
    private String codeRattachementAutres = StringUtils.EMPTY;

    /** The rattachement externe. */
    private String rattachementExterne = StringUtils.EMPTY;

    /** The id bandeau. */
    private Long idBandeau = 0L;

    /** The onglets. */
    private String onglets = StringUtils.EMPTY;

    /** The couleur titre. */
    private String couleurTitre = StringUtils.EMPTY;

    /** The couleur fond. */
    private String couleurFond = StringUtils.EMPTY;

    /** The adresse. */
    private String adresse = StringUtils.EMPTY;

    /** The code postal. */
    private String codePostal = StringUtils.EMPTY;

    /** The ville. */
    private String ville = StringUtils.EMPTY;

    /** The villes. */
    @Label(contexte = "rechercheetlabo", type = "22")
    private String villes = StringUtils.EMPTY;

    /** The telephone. */
    private String telephone = StringUtils.EMPTY;

    /** The telecopie. */
    private String telecopie = StringUtils.EMPTY;

    /** The adresse mail. */
    private String adresseMail = StringUtils.EMPTY;

    /** The site web. */
    private String siteWeb = StringUtils.EMPTY;

    /** The code responsable. */
    @Fiche(contexte = "rechercheetlabo", nomObjet = "annuaireksup")
    private String codeResponsable = StringUtils.EMPTY;

    /** The composition. */
    private String composition = StringUtils.EMPTY;

    /** The axe recherche etablissement. */
    @Label(contexte = "rechercheetlabo", type = "61")
    private String axeRechercheEtablissement = StringUtils.EMPTY;

    /** The axes recherche. */
    private String axesRecherche = StringUtils.EMPTY;

    /** The domaine application. */
    @Label(contexte = "rechercheetlabo", type = "62")
    private String domaineApplication = StringUtils.EMPTY;

    /** The langues parlees. */
    private String languesParlees = StringUtils.EMPTY;

    /** The formations. */
    private String formations = StringUtils.EMPTY;

    /** The publications. */
    private String publications = StringUtils.EMPTY;

    /** The equipements. */
    private String equipements = StringUtils.EMPTY;

    /** The cooperations internationales. */
    private String cooperationsInternationales = StringUtils.EMPTY;

    /** The collaborations universitaires. */
    private String collaborationsUniversitaires = StringUtils.EMPTY;

    /** The cooperations industrielles. */
    private String cooperationsIndustrielles = StringUtils.EMPTY;

    /** The chiffres cles. */
    private String chiffresCles = StringUtils.EMPTY;

    /** The complement coordonnees. */
    private String complementCoordonnees = StringUtils.EMPTY;

    /** The complements. */
    private String complements = StringUtils.EMPTY;

    /** The id plan acces. */
    private Long idPlanAcces = 0L;

    /** The id photo. */
    private Long idPhoto = 0L;

    /**
     * Gets the libelle court.
     *
     * @return the libelle court
     */
    public String getLibelleCourt() {
        return libelleCourt;
    }

    /**
     * Sets the libelle court.
     *
     * @param libelleCourt
     *            the new libelle court
     */
    public void setLibelleCourt(String libelleCourt) {
        this.libelleCourt = libelleCourt;
    }

    /**
     * Gets the libelle long.
     *
     * @return the libelle long
     */
    @Override
    public String getLibelleLong() {
        return libelleLong;
    }

    /**
     * Sets the libelle long.
     *
     * @param libelleLong
     *            the new libelle long
     */
    public void setLibelleLong(String libelleLong) {
        this.libelleLong = libelleLong;
    }

    /**
     * Gets the type laboratoire.
     *
     * @return the type laboratoire
     */
    public String getTypeLaboratoire() {
        return typeLaboratoire;
    }

    /**
     * Sets the type laboratoire.
     *
     * @param typeLaboratoire
     *            the new type laboratoire
     */
    public void setTypeLaboratoire(String typeLaboratoire) {
        this.typeLaboratoire = typeLaboratoire;
    }

    /**
     * Gets the structure enseignement.
     *
     * @return the structure enseignement
     */
    public String getStructureEnseignement() {
        return structureEnseignement;
    }

    /**
     * Sets the structure enseignement.
     *
     * @param structureEnseignement
     *            the new structure enseignement
     */
    public void setStructureEnseignement(String structureEnseignement) {
        this.structureEnseignement = structureEnseignement;
    }

    /**
     * Gets the reference umr.
     *
     * @return the reference umr
     */
    public String getReferenceUmr() {
        return referenceUmr;
    }

    /**
     * Sets the reference umr.
     *
     * @param referenceUmr
     *            the new reference umr
     */
    public void setReferenceUmr(String referenceUmr) {
        this.referenceUmr = referenceUmr;
    }

    /**
     * Gets the reconnaissance.
     *
     * @return the reconnaissance
     */
    public String getReconnaissance() {
        return reconnaissance;
    }

    /**
     * Sets the reconnaissance.
     *
     * @param reconnaissance
     *            the new reconnaissance
     */
    public void setReconnaissance(String reconnaissance) {
        this.reconnaissance = reconnaissance;
    }

    /**
     * Gets the direction scientifique.
     *
     * @return the direction scientifique
     */
    public String getDirectionScientifique() {
        return directionScientifique;
    }

    /**
     * Sets the direction scientifique.
     *
     * @param directionScientifique
     *            the new direction scientifique
     */
    public void setDirectionScientifique(String directionScientifique) {
        this.directionScientifique = directionScientifique;
    }

    /**
     * Gets the code rattachement autres.
     *
     * @return the code rattachement autres
     */
    public String getCodeRattachementAutres() {
        return codeRattachementAutres;
    }

    /**
     * Sets the code rattachement autres.
     *
     * @param codeRattachementAutres
     *            the new code rattachement autres
     */
    public void setCodeRattachementAutres(String codeRattachementAutres) {
        this.codeRattachementAutres = codeRattachementAutres;
    }

    /**
     * Gets the rattachement externe.
     *
     * @return the rattachement externe
     */
    public String getRattachementExterne() {
        return rattachementExterne;
    }

    /**
     * Sets the rattachement externe.
     *
     * @param rattachementExterne
     *            the new rattachement externe
     */
    public void setRattachementExterne(String rattachementExterne) {
        this.rattachementExterne = rattachementExterne;
    }

    /**
     * Gets the id bandeau.
     *
     * @return the id bandeau
     */
    @GetterAnnotation(isIdMedia = true)
    public Long getIdBandeau() {
        return idBandeau;
    }

    /**
     * Sets the id bandeau.
     *
     * @param idBandeau
     *            the new id bandeau
     */
    @SetterAnnotation(isIdMedia = true)
    public void setIdBandeau(Long idBandeau) {
        this.idBandeau = idBandeau;
    }

    /**
     * Gets the onglets.
     *
     * @return the onglets
     */
    @GetterAnnotation(isToolbox = true)
    public String getOnglets() {
        return onglets;
    }

    /**
     * Sets the onglets.
     *
     * @param onglets
     *            the new onglets
     */
    @SetterAnnotation(isToolbox = true)
    public void setOnglets(String onglets) {
        this.onglets = onglets;
    }

    /**
     * Gets the couleur titre.
     *
     * @return the couleur titre
     */
    public String getCouleurTitre() {
        return couleurTitre;
    }

    /**
     * Sets the couleur titre.
     *
     * @param couleurTitre
     *            the new couleur titre
     */
    public void setCouleurTitre(String couleurTitre) {
        this.couleurTitre = couleurTitre;
    }

    /**
     * Gets the couleur fond.
     *
     * @return the couleur fond
     */
    public String getCouleurFond() {
        return couleurFond;
    }

    /**
     * Sets the couleur fond.
     *
     * @param couleurFond
     *            the new couleur fond
     */
    public void setCouleurFond(String couleurFond) {
        this.couleurFond = couleurFond;
    }

    /**
     * Gets the adresse.
     *
     * @return the adresse
     */
    public String getAdresse() {
        return adresse;
    }

    /**
     * Sets the adresse.
     *
     * @param adresse
     *            the new adresse
     */
    public void setAdresse(String adresse) {
        this.adresse = adresse;
    }

    /**
     * Gets the code postal.
     *
     * @return the code postal
     */
    public String getCodePostal() {
        return codePostal;
    }

    /**
     * Sets the code postal.
     *
     * @param codePostal
     *            the new code postal
     */
    public void setCodePostal(String codePostal) {
        this.codePostal = codePostal;
    }

    /**
     * Gets the ville.
     *
     * @return the ville
     */
    public String getVille() {
        return ville;
    }

    /**
     * Sets the ville.
     *
     * @param ville
     *            the new ville
     */
    public void setVille(String ville) {
        this.ville = ville;
    }

    /**
     * Gets the villes.
     *
     * @return the villes
     */
    public String getVilles() {
        return villes;
    }

    /**
     * Sets the villes.
     *
     * @param villes
     *            the new villes
     */
    public void setVilles(String villes) {
        this.villes = villes;
    }

    /**
     * Gets the telephone.
     *
     * @return the telephone
     */
    public String getTelephone() {
        return telephone;
    }

    /**
     * Sets the telephone.
     *
     * @param telephone
     *            the new telephone
     */
    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }

    /**
     * Gets the telecopie.
     *
     * @return the telecopie
     */
    public String getTelecopie() {
        return telecopie;
    }

    /**
     * Sets the telecopie.
     *
     * @param telecopie
     *            the new telecopie
     */
    public void setTelecopie(String telecopie) {
        this.telecopie = telecopie;
    }

    /**
     * Gets the adresse mail.
     *
     * @return the adresse mail
     */
    public String getAdresseMail() {
        return adresseMail;
    }

    /**
     * Sets the adresse mail.
     *
     * @param adresseMail
     *            the new adresse mail
     */
    public void setAdresseMail(String adresseMail) {
        this.adresseMail = adresseMail;
    }

    /**
     * Gets the site web.
     *
     * @return the site web
     */
    public String getSiteWeb() {
        return siteWeb;
    }

    /**
     * Sets the site web.
     *
     * @param siteWeb
     *            the new site web
     */
    public void setSiteWeb(String siteWeb) {
        this.siteWeb = siteWeb;
    }

    /**
     * Gets the code responsable.
     *
     * @return the code responsable
     */
    public String getCodeResponsable() {
        return codeResponsable;
    }

    /**
     * Sets the code responsable.
     *
     * @param codeResponsable
     *            the new code responsable
     */
    public void setCodeResponsable(String codeResponsable) {
        this.codeResponsable = codeResponsable;
    }

    /**
     * Gets the composition.
     *
     * @return the composition
     */
    @GetterAnnotation(isToolbox = true)
    public String getComposition() {
        return composition;
    }

    /**
     * Sets the composition.
     *
     * @param composition
     *            the new composition
     */
    @SetterAnnotation(isToolbox = true)
    public void setComposition(String composition) {
        this.composition = composition;
    }

    /**
     * Gets the axe recherche etablissement.
     *
     * @return the axe recherche etablissement
     */
    public String getAxeRechercheEtablissement() {
        return axeRechercheEtablissement;
    }

    /**
     * Sets the axe recherche etablissement.
     *
     * @param axeRechercheEtablissement
     *            the new axe recherche etablissement
     */
    public void setAxeRechercheEtablissement(String axeRechercheEtablissement) {
        this.axeRechercheEtablissement = axeRechercheEtablissement;
    }

    /**
     * Gets the axes recherche.
     *
     * @return the axes recherche
     */
    @GetterAnnotation(isToolbox = true)
    public String getAxesRecherche() {
        return axesRecherche;
    }

    /**
     * Sets the axes recherche.
     *
     * @param axesRecherche
     *            the new axes recherche
     */
    @SetterAnnotation(isToolbox = true)
    public void setAxesRecherche(String axesRecherche) {
        this.axesRecherche = axesRecherche;
    }

    /**
     * Gets the domaine application.
     *
     * @return the domaine application
     */
    public String getDomaineApplication() {
        return domaineApplication;
    }

    /**
     * Sets the domaine application.
     *
     * @param domaineApplication
     *            the new domaine application
     */
    public void setDomaineApplication(String domaineApplication) {
        this.domaineApplication = domaineApplication;
    }

    /**
     * Gets the langues parlees.
     *
     * @return the langues parlees
     */
    public String getLanguesParlees() {
        return languesParlees;
    }

    /**
     * Sets the langues parlees.
     *
     * @param languesParlees
     *            the new langues parlees
     */
    public void setLanguesParlees(String languesParlees) {
        this.languesParlees = languesParlees;
    }

    /**
     * Gets the formations.
     *
     * @return the formations
     */
    @GetterAnnotation(isToolbox = true)
    public String getFormations() {
        return formations;
    }

    /**
     * Sets the formations.
     *
     * @param formations
     *            the new formations
     */
    @SetterAnnotation(isToolbox = true)
    public void setFormations(String formations) {
        this.formations = formations;
    }

    /**
     * Gets the publications.
     *
     * @return the publications
     */
    @GetterAnnotation(isToolbox = true)
    public String getPublications() {
        return publications;
    }

    /**
     * Sets the publications.
     *
     * @param publications
     *            the new publications
     */
    @SetterAnnotation(isToolbox = true)
    public void setPublications(String publications) {
        this.publications = publications;
    }

    /**
     * Gets the equipements.
     *
     * @return the equipements
     */
    @GetterAnnotation(isToolbox = true)
    public String getEquipements() {
        return equipements;
    }

    /**
     * Sets the equipements.
     *
     * @param equipements
     *            the new equipements
     */
    @SetterAnnotation(isToolbox = true)
    public void setEquipements(String equipements) {
        this.equipements = equipements;
    }

    /**
     * Gets the cooperations internationales.
     *
     * @return the cooperations internationales
     */
    @GetterAnnotation(isToolbox = true)
    public String getCooperationsInternationales() {
        return cooperationsInternationales;
    }

    /**
     * Sets the cooperations internationales.
     *
     * @param cooperationsInternationales
     *            the new cooperations internationales
     */
    @SetterAnnotation(isToolbox = true)
    public void setCooperationsInternationales(String cooperationsInternationales) {
        this.cooperationsInternationales = cooperationsInternationales;
    }

    /**
     * Gets the collaborations universitaires.
     *
     * @return the collaborations universitaires
     */
    @GetterAnnotation(isToolbox = true)
    public String getCollaborationsUniversitaires() {
        return collaborationsUniversitaires;
    }

    /**
     * Sets the collaborations universitaires.
     *
     * @param collaborationsUniversitaires
     *            the new collaborations universitaires
     */
    @SetterAnnotation(isToolbox = true)
    public void setCollaborationsUniversitaires(String collaborationsUniversitaires) {
        this.collaborationsUniversitaires = collaborationsUniversitaires;
    }

    /**
     * Gets the cooperations industrielles.
     *
     * @return the cooperations industrielles
     */
    @GetterAnnotation(isToolbox = true)
    public String getCooperationsIndustrielles() {
        return cooperationsIndustrielles;
    }

    /**
     * Sets the cooperations industrielles.
     *
     * @param cooperationsIndustrielles
     *            the new cooperations industrielles
     */
    @SetterAnnotation(isToolbox = true)
    public void setCooperationsIndustrielles(String cooperationsIndustrielles) {
        this.cooperationsIndustrielles = cooperationsIndustrielles;
    }

    /**
     * Gets the chiffres cles.
     *
     * @return the chiffres cles
     */
    @GetterAnnotation(isToolbox = true)
    public String getChiffresCles() {
        return chiffresCles;
    }

    /**
     * Sets the chiffres cles.
     *
     * @param chiffresCles
     *            the new chiffres cles
     */
    @SetterAnnotation(isToolbox = true)
    public void setChiffresCles(String chiffresCles) {
        this.chiffresCles = chiffresCles;
    }

    /**
     * Gets the complement coordonnees.
     *
     * @return the complement coordonnees
     */
    @GetterAnnotation(isToolbox = true)
    public String getComplementCoordonnees() {
        return complementCoordonnees;
    }

    /**
     * Sets the complement coordonnees.
     *
     * @param complementCoordonnees
     *            the new complement coordonnees
     */
    @SetterAnnotation(isToolbox = true)
    public void setComplementCoordonnees(String complementCoordonnees) {
        this.complementCoordonnees = complementCoordonnees;
    }

    /**
     * Gets the complements.
     *
     * @return the complements
     */
    @GetterAnnotation(isToolbox = true)
    public String getComplements() {
        return complements;
    }

    /**
     * Sets the complements.
     *
     * @param complements
     *            the new complements
     */
    @SetterAnnotation(isToolbox = true)
    public void setComplements(String complements) {
        this.complements = complements;
    }

    /**
     * Gets the id plan acces.
     *
     * @return the id plan acces
     */
    @GetterAnnotation(isIdMedia = true)
    public Long getIdPlanAcces() {
        return idPlanAcces;
    }

    /**
     * Sets the id plan acces.
     *
     * @param idPlanAcces
     *            the new id plan acces
     */
    @SetterAnnotation(isIdMedia = true)
    public void setIdPlanAcces(Long idPlanAcces) {
        this.idPlanAcces = idPlanAcces;
    }

    /**
     * Gets the id photo.
     *
     * @return the id photo
     */
    @GetterAnnotation(isIdMedia = true)
    public Long getIdPhoto() {
        return idPhoto;
    }

    /**
     * Sets the id photo.
     *
     * @param idPhoto
     *            the new id photo
     */
    @SetterAnnotation(isIdMedia = true)
    public void setIdPhoto(Long idPhoto) {
        this.idPhoto = idPhoto;
    }
}
