/**
 * Copyright (C) 2015 - 2018 Kosmos contact@kosmos.fr
 *
 * Projet: rechercheetlabo
 * Version: 1.08.00
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.ksup.objetspartages.misc;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;

import com.jsbsoft.jtf.core.InfoBean;
import com.jsbsoft.jtf.core.LangueUtil;
import com.jsbsoft.jtf.database.OMContext;
import com.jsbsoft.jtf.exception.ErreurApplicative;
import com.kosmos.service.impl.ServiceManager;
import com.kportal.cms.objetspartages.Objetpartage;
import com.univ.objetspartages.om.AbstractRechercheExterne;
import com.univ.objetspartages.om.ReferentielObjets;
import com.univ.objetspartages.om.StructureModele;
import com.univ.objetspartages.services.ServiceStructure;
import com.univ.objetspartages.util.CritereRecherche;
import com.univ.objetspartages.util.LabelUtils;
import com.univ.utils.RechercheFicheHelper;

import static com.univ.objetspartages.util.CritereRechercheUtil.getCritereChaineAvecFichierDat;
import static com.univ.objetspartages.util.CritereRechercheUtil.getCritereChaineAvecLibelle;
import static com.univ.objetspartages.util.CritereRechercheUtil.getCritereTexteNonVideFormater;

public class RechercheRechercheetlabo extends AbstractRechercheExterne {

    /**
     * Prepare le formulaire de recherche.
     *
     * @param infoBean
     *            the info bean
     * @param ctx
     *            the ctx
     *
     * @return true, if preparer recherche
     *
     */
    @Override
    public boolean preparerRECHERCHE(final InfoBean infoBean, final OMContext ctx) {
        final ServiceStructure serviceStructure = ServiceManager.getServiceForBean(StructureModele.class);
        boolean rechercheEffectuee = false;
        StringUtils.defaultString(infoBean.getString("OBJET"), "");
        final Locale locale = ctx.getLocale();
        if (infoBean.getString("OBJET").equalsIgnoreCase("LABORATOIRE")) {
            infoBean.set("LISTE_STRUCTURES", serviceStructure.getSubStructures(StringUtils.EMPTY, String.valueOf(LangueUtil.getIndiceLocale(locale)), true));
            infoBean.set("LISTE_TYPE_LABORATOIRES", LabelUtils.getLabelCombo("63", locale));
            infoBean.set("LISTE_AXE_RECHERCHE_ETABLISSEMENTS", LabelUtils.getLabelCombo("61", locale));
            infoBean.set("LISTE_DOMAINE_APPLICATIONS", LabelUtils.getLabelCombo("62", locale));
            rechercheEffectuee = true;
        }
        return rechercheEffectuee;
    }

    /**
     * Traite la recherche.
     *
     * @param infoBean
     *            the info bean
     * @param ctx
     *            the ctx
     *
     * @return true, if traiter recherche
     *
     * @throws Exception
     *             the exception
     */
    @Override
    public boolean traiterRECHERCHE(final InfoBean infoBean, final OMContext ctx) throws ErreurApplicative {
        boolean rechercheEffectuee = false;
        final String objet = infoBean.getString("OBJET").toUpperCase();
        if (objet.equals("LABORATOIRE")) {
            final List<CritereRecherche> criteres = new ArrayList<>();
            criteres.add(new CritereRecherche("OBJET", objet, StringUtils.EMPTY));
            final Objetpartage module = ReferentielObjets.getObjetByNom(objet);
            CollectionUtils.addIgnoreNull(criteres, getCritereTexteNonVideFormater(infoBean, "LIBELLE"));
            CollectionUtils.addIgnoreNull(criteres, getCritereChaineAvecLibelle(infoBean, "TYPE_LABORATOIRE", "63"));
            CollectionUtils.addIgnoreNull(criteres, getCritereTexteNonVideFormater(infoBean, "REFERENCE_UMR"));
            final String structureEnseignement = infoBean.getString("STRUCTURE_ENSEIGNEMENT");
            if ("0".equals(structureEnseignement) || "1".equals(structureEnseignement)) {
                final String libelleStructEnseignement = module.getMessage("JTF_LABORATOIRE_STRUCTURE_ENSEIGNEMENT_" + infoBean.getString("STRUCTURE_ENSEIGNEMENT"));
                criteres.add(new CritereRecherche("STRUCTURE_ENSEIGNEMENT", structureEnseignement, libelleStructEnseignement));
            }
            CollectionUtils.addIgnoreNull(criteres, getCritereChaineAvecFichierDat(infoBean, "DIRECTION_SCIENTIFIQUE", "direction_scientifique", module.getIdExtension()));
            CollectionUtils.addIgnoreNull(criteres, getCritereChaineAvecLibelle(infoBean, "AXE_RECHERCHE_ETABLISSEMENT", "61"));
            CollectionUtils.addIgnoreNull(criteres, getCritereTexteNonVideFormater(infoBean, "THEME"));
            CollectionUtils.addIgnoreNull(criteres, getCritereChaineAvecLibelle(infoBean, "DOMAINE_APPLICATION", "62"));
            if ("0".equals(module.getProperty("fiche.LABORATOIRE.recherche_vide")) && criteres.size() <= 1) {
                throw new ErreurApplicative(module.getMessage(ctx.getLocale(), "ST_RECHERCHE_SAISIR_UN_CRITERE"));
            }
            rechercheEffectuee = true;
            // attribut commun à toute les fiches
            criteres.addAll(getCritereDefaut(infoBean));
            infoBean.set(RechercheFicheHelper.ATTRIBUT_INFOBEAN_CRITERES, criteres);
            gestionAncienFront(infoBean, criteres);
        }
        return rechercheEffectuee;
    }

    @Override
    public List<String> getCriteresRequete(final String objet, final boolean listeIncluse) {
        final List<String> criteres = new ArrayList<>();
        if (objet.equals("LABORATOIRE")) {
            criteres.add("TYPE_LABORATOIRE");
            criteres.add("STRUCTURE_ENSEIGNEMENT");
            criteres.add("DIRECTION_SCIENTIFIQUE");
            criteres.add("AXE_RECHERCHE_ETABLISSEMENT");
            criteres.add("DOMAINE_APPLICATION");
        }
        return criteres;
    }
}
