/**
 * Copyright (C) 2015 - 2018 Kosmos contact@kosmos.fr
 *
 * Projet: rechercheetlabo
 * Version: 1.08.00
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.ksup.objetspartages.processus;

import org.apache.commons.lang3.StringUtils;

import com.jsbsoft.jtf.core.InfoBean;
import com.jsbsoft.jtf.core.LangueUtil;
import com.jsbsoft.jtf.exception.ErreurApplicative;
import com.jsbsoft.jtf.session.SessionUtilisateur;
import com.kosmos.service.impl.ServiceManager;
import com.ksup.objetspartages.om.Laboratoire;
import com.univ.objetspartages.bean.MediaBean;
import com.univ.objetspartages.om.AutorisationBean;
import com.univ.objetspartages.om.StructureModele;
import com.univ.objetspartages.processus.ControleurUniv;
import com.univ.objetspartages.processus.SaisieFiche;
import com.univ.objetspartages.services.ServiceMedia;
import com.univ.objetspartages.services.ServiceStructure;
import com.univ.objetspartages.util.LabelUtils;
import com.univ.objetspartages.util.MediaUtils;

/**
 * Processus de gestion des laboratoires.
 */
public class SaisieLaboratoire extends SaisieFiche {

    private final ServiceMedia serviceMedia;

    protected Laboratoire laboratoire = null;

    /**
     * Constructeur.
     *
     * @param infoBean l'{@link com.jsbsoft.jtf.core.InfoBean} courant.
     */
    public SaisieLaboratoire(final InfoBean infoBean) {
        super(infoBean);
        serviceMedia = ServiceManager.getServiceForBean(MediaBean.class);
    }

    /**
     * Point d'entree du processus.
     */
    @Override
    public boolean traiterAction() throws Exception {
        infoBean.set("CODE_OBJET", "0020");
        laboratoire = new Laboratoire();
        laboratoire.init();
        final AutorisationBean autorisations = (AutorisationBean) getGp().getSessionUtilisateur().getInfos().get(SessionUtilisateur.AUTORISATIONS);
        if (autorisations != null) {
            this.getDatas().put("AUTORISATIONS", autorisations);
        }
        traiterActionParDefaut(laboratoire);
        infoBean.set("NOM_ONGLET", "laboratoire");
        // on continue si on n'est pas a la FIN !!!
        return etat == FIN;
    }

    @Override
    protected void preparerRECHERCHE() {
        infoBean.set("LISTE_LANGUES", LangueUtil.getListeLangues(this.getLocale()));
        infoBean.set("LISTE_TYPE_LABORATOIRES", LabelUtils.getLabelCombo("63", this.getLocale()));
        infoBean.set("LISTE_VILLESS", LabelUtils.getLabelCombo("22", this.getLocale()));
        infoBean.set("LISTE_AXE_RECHERCHE_ETABLISSEMENTS", LabelUtils.getLabelCombo("61", this.getLocale()));
        infoBean.set("LISTE_DOMAINE_APPLICATIONS", LabelUtils.getLabelCombo("62", this.getLocale()));
    }

    @Override
    protected void prepareRestrictedSearch(final String sectionCode) {
        infoBean.set("LISTE_LANGUES", LangueUtil.getListeLangues(this.getLocale()));
        infoBean.set("LISTE_TYPE_LABORATOIRES", LabelUtils.getLabelComboWithRestrictionInformation("63", this.getLocale()));
        infoBean.set("LISTE_VILLESS", LabelUtils.getLabelComboWithRestrictionInformation("22", this.getLocale()));
        infoBean.set("LISTE_AXE_RECHERCHE_ETABLISSEMENTS", LabelUtils.getLabelComboWithRestrictionInformation("61", this.getLocale()));
        infoBean.set("LISTE_DOMAINE_APPLICATIONS", LabelUtils.getLabelComboWithRestrictionInformation("62", this.getLocale()));
    }

    /**
     * Affichage de l'ecran de saisie d'un(e) laboratoire.
     */
    @Override
    protected void preparerPRINCIPAL() throws Exception {
        ecranLogique = ECRAN_PRINCIPAL;
        infoBean.set("ID_LABORATOIRE", laboratoire.getIdLaboratoire().toString());
        infoBean.set("LIBELLE_COURT", laboratoire.getLibelleCourt());
        infoBean.set("LIBELLE_LONG", laboratoire.getLibelleLong());
        infoBean.set("TYPE_LABORATOIRE", laboratoire.getTypeLaboratoire());
        infoBean.set("LISTE_TYPE_LABORATOIRES", LabelUtils.getLabelForComboForSection("63", laboratoire.getLangue(), getCurrentSection(laboratoire.getPersistanceBean())));
        infoBean.set("STRUCTURE_ENSEIGNEMENT", laboratoire.getStructureEnseignement());
        infoBean.set("REFERENCE_UMR", laboratoire.getReferenceUmr());
        infoBean.set("RECONNAISSANCE", laboratoire.getReconnaissance());
        infoBean.set("DIRECTION_SCIENTIFIQUE", laboratoire.getDirectionScientifique());
        infoBean.set("CODE_RATTACHEMENT_AUTRES", laboratoire.getCodeRattachementAutres());
        infoBean.set("LIBELLE_CODE_RATTACHEMENT_AUTRES", laboratoire.getLibelleCodeRattachementAutres());
        infoBean.set("RATTACHEMENT_EXTERNE", laboratoire.getRattachementExterne());
        infoBean.set("ID_BANDEAU", laboratoire.getIdBandeau().toString());
        infoBean.set("ONGLETS", laboratoire.getOnglets());
        infoBean.set("COULEUR_TITRE", laboratoire.getCouleurTitre());
        infoBean.set("COULEUR_FOND", laboratoire.getCouleurFond());
        infoBean.set("ADRESSE", laboratoire.getAdresse());
        infoBean.set("CODE_POSTAL", laboratoire.getCodePostal());
        infoBean.set("VILLE", laboratoire.getVille());
        infoBean.set("VILLES", laboratoire.getVilles());
        infoBean.set("LIBELLE_VILLES", LabelUtils.getLibelleWithSection("22", laboratoire.getVilles(), laboratoire.getLangue(), getCurrentSection(laboratoire.getPersistanceBean())));
        infoBean.set("LISTE_VILLESS", LabelUtils.getLabelForComboForSection("22", laboratoire.getLangue(), getCurrentSection(laboratoire.getPersistanceBean())));
        infoBean.set("TELEPHONE", laboratoire.getTelephone());
        infoBean.set("TELECOPIE", laboratoire.getTelecopie());
        infoBean.set("ADRESSE_MAIL", laboratoire.getAdresseMail());
        infoBean.set("SITE_WEB", laboratoire.getSiteWeb());
        infoBean.set("CODE_RESPONSABLE", laboratoire.getCodeResponsable());
        infoBean.set("LIBELLE_CODE_RESPONSABLE", laboratoire.getLibelleCodeResponsable());
        infoBean.set("COMPOSITION", laboratoire.getComposition());
        infoBean.set("AXE_RECHERCHE_ETABLISSEMENT", laboratoire.getAxeRechercheEtablissement());
        infoBean.set("LIBELLE_AXE_RECHERCHE_ETABLISSEMENT", LabelUtils.getLibelleWithSection("61", laboratoire.getAxeRechercheEtablissement(), laboratoire.getLangue(), getCurrentSection(laboratoire.getPersistanceBean())));
        infoBean.set("LISTE_AXE_RECHERCHE_ETABLISSEMENTS", LabelUtils.getLabelForComboForSection("61", laboratoire.getLangue(), getCurrentSection(laboratoire.getPersistanceBean())));
        infoBean.set("AXE_RECHERCHE", laboratoire.getAxesRecherche());
        infoBean.set("DOMAINE_APPLICATION", laboratoire.getDomaineApplication());
        infoBean.set("LIBELLE_DOMAINE_APPLICATION", LabelUtils.getLibelleWithSection("62", laboratoire.getDomaineApplication(), laboratoire.getLangue(), getCurrentSection(laboratoire.getPersistanceBean())));
        infoBean.set("LISTE_DOMAINE_APPLICATIONS", LabelUtils.getLabelForComboForSection("62", laboratoire.getLangue(), getCurrentSection(laboratoire.getPersistanceBean())));
        infoBean.set("LANGUES_PARLEES", laboratoire.getLanguesParlees());
        infoBean.set("FORMATIONS", laboratoire.getFormations());
        infoBean.set("PUBLICATIONS", laboratoire.getPublications());
        infoBean.set("EQUIPEMENTS", laboratoire.getEquipements());
        infoBean.set("COOPERATIONS_INTERNATIONALES", laboratoire.getCooperationsInternationales());
        infoBean.set("COLLABORATIONS_UNIVERSITAIRES", laboratoire.getCollaborationsUniversitaires());
        infoBean.set("COOPERATIONS_INDUSTRIELLES", laboratoire.getCooperationsIndustrielles());
        infoBean.set("CHIFFRES_CLES", laboratoire.getChiffresCles());
        infoBean.set("COMPLEMENT_COORDONNEES", laboratoire.getComplementCoordonnees());
        infoBean.set("COMPLEMENTS", laboratoire.getComplements());
        infoBean.set("ID_PLAN_ACCES", laboratoire.getIdPlanAcces().toString());
        final MediaBean mediaBean = serviceMedia.getById(laboratoire.getIdPlanAcces());
        infoBean.set("LIBELLE_ID_PLAN_ACCES", mediaBean != null ? StringUtils.defaultIfBlank(mediaBean.getTitre(), StringUtils.EMPTY) : StringUtils.EMPTY);
        infoBean.set("LISTE_PLANS_ACCES", MediaUtils.getMediasAsMap(serviceMedia.getByTypeAndTypeMedia("photo", "0003")));
        infoBean.set("ID_PHOTO", laboratoire.getIdPhoto().toString());
        infoBean.set("CODE_RATTACHEMENT", laboratoire.getCodeRattachement());
        final ServiceStructure serviceStructure = ServiceManager.getServiceForBean(StructureModele.class);
        infoBean.set("LIBELLE_CODE_RATTACHEMENT", serviceStructure.getDisplayableLabel(laboratoire.getCodeRattachement(), laboratoire.getLangue()));
        infoBean.set("LIBELLE_AFFICHABLE", StringUtils.defaultIfBlank(laboratoire.getLibelleLong(), laboratoire.getLibelleCourt()));
        if (infoBean.get("SAISIE_FRONT") == null) {
            infoBean.set("SOUS_ONGLET", "PRINCIPAL"); // onglet par defaut
        }
        ControleurUniv.preparerPRINCIPAL(infoBean, laboratoire, this);
    }

    @Override
    protected void alimenterDonneesFiche() throws Exception {
        laboratoire.setLibelleCourt((String) infoBean.get("LIBELLE_COURT"));
        laboratoire.setLibelleLong((String) infoBean.get("LIBELLE_LONG"));
        laboratoire.setTypeLaboratoire((String) infoBean.get("TYPE_LABORATOIRE"));
        laboratoire.setStructureEnseignement((String) infoBean.get("STRUCTURE_ENSEIGNEMENT"));
        laboratoire.setReferenceUmr((String) infoBean.get("REFERENCE_UMR"));
        laboratoire.setReconnaissance((String) infoBean.get("RECONNAISSANCE"));
        laboratoire.setDirectionScientifique((String) infoBean.get("DIRECTION_SCIENTIFIQUE"));
        laboratoire.setCodeRattachementAutres((String) infoBean.get("CODE_RATTACHEMENT_AUTRES"));
        laboratoire.setRattachementExterne((String) infoBean.get("RATTACHEMENT_EXTERNE"));
        laboratoire.setIdBandeau(new Long(infoBean.getString("ID_BANDEAU")));
        laboratoire.setOnglets((String) infoBean.get("ONGLETS"));
        laboratoire.setCouleurTitre((String) infoBean.get("COULEUR_TITRE"));
        laboratoire.setCouleurFond((String) infoBean.get("COULEUR_FOND"));
        laboratoire.setAdresse((String) infoBean.get("ADRESSE"));
        laboratoire.setCodePostal((String) infoBean.get("CODE_POSTAL"));
        laboratoire.setVille((String) infoBean.get("VILLE"));
        laboratoire.setVilles((String) infoBean.get("VILLES"));
        laboratoire.setTelephone((String) infoBean.get("TELEPHONE"));
        laboratoire.setTelecopie((String) infoBean.get("TELECOPIE"));
        laboratoire.setAdresseMail((String) infoBean.get("ADRESSE_MAIL"));
        laboratoire.setSiteWeb((String) infoBean.get("SITE_WEB"));
        laboratoire.setCodeResponsable((String) infoBean.get("CODE_RESPONSABLE"));
        laboratoire.setComposition((String) infoBean.get("COMPOSITION"));
        laboratoire.setAxeRechercheEtablissement((String) infoBean.get("AXE_RECHERCHE_ETABLISSEMENT"));
        laboratoire.setAxesRecherche((String) infoBean.get("AXE_RECHERCHE"));
        laboratoire.setDomaineApplication((String) infoBean.get("DOMAINE_APPLICATION"));
        laboratoire.setLanguesParlees((String) infoBean.get("LANGUES_PARLEES"));
        laboratoire.setFormations((String) infoBean.get("FORMATIONS"));
        laboratoire.setPublications((String) infoBean.get("PUBLICATIONS"));
        laboratoire.setEquipements((String) infoBean.get("EQUIPEMENTS"));
        laboratoire.setCooperationsInternationales((String) infoBean.get("COOPERATIONS_INTERNATIONALES"));
        laboratoire.setCollaborationsUniversitaires((String) infoBean.get("COLLABORATIONS_UNIVERSITAIRES"));
        laboratoire.setCooperationsIndustrielles((String) infoBean.get("COOPERATIONS_INDUSTRIELLES"));
        laboratoire.setChiffresCles((String) infoBean.get("CHIFFRES_CLES"));
        laboratoire.setComplementCoordonnees((String) infoBean.get("COMPLEMENT_COORDONNEES"));
        laboratoire.setComplements((String) infoBean.get("COMPLEMENTS"));
        laboratoire.setIdPlanAcces(new Long(infoBean.getString("ID_PLAN_ACCES")));
        laboratoire.setIdPhoto(new Long(infoBean.getString("ID_PHOTO")));
        laboratoire.setCodeRubrique(infoBean.getString("CODE_RUBRIQUE"));
        if (infoBean.getString("CODE_RATTACHEMENT").length() > 0) {
            if (laboratoire.getCode().equals(infoBean.getString("CODE_RATTACHEMENT"))) {
                throw new ErreurApplicative("Il n'est pas possible de rattacher un laboratoire à lui-même.");
            }
            laboratoire.setCodeRattachement(infoBean.getString("CODE_RATTACHEMENT"));
        } else {
            laboratoire.setCodeRattachement("");
        }
        laboratoire.setCodeRattachement(infoBean.getString("CODE_RATTACHEMENT"));
    }

    /**
     * Traite l'ecran de saisie d'une fiche.
     */
    @Override
    protected void traiterPRINCIPAL() throws Exception {
        // chargement de l'objet
        if (infoBean.getEtatObjet().equals(InfoBean.ETAT_OBJET_CREATION)) {
            laboratoire.init();
        } else {
            laboratoire.setIdLaboratoire(Long.valueOf(infoBean.getString("ID_LABORATOIRE")));
            laboratoire.retrieve();
        }
        // changement d'onglet
        if (action.equals(InfoBean.ACTION_ONGLET)) {
            infoBean.set("SOUS_ONGLET", infoBean.getString("SOUS_ONGLET_DEMANDE"));
        }
        // validation de l'ecran
        else if (action.equals(InfoBean.ACTION_ENREGISTRER)) {
            alimenteCodeSiVide(infoBean);
            alimenteDonneesCreation(laboratoire, true);
            alimenterDonneesFiche();
        }
        // appel au traitement general
        ecranLogique = ControleurUniv.traiterPRINCIPAL(infoBean, laboratoire, this);
        if (ecranLogique.length() == 0) {
            etat = FIN;
        }
    }
}
